<?php


/**
 * @file
 * Provide interface for adjusting TrustCommerce settings
 * 
 */


/**
 * TrustCommerce Settings Page
 */
function trustcommerce_settings() {
  $form = array();

  $form['trustcommerce_url'] = array(
    '#type' => 'textfield',
    '#title' => t('URL for transactions'),
    '#default_value' => variable_get('trustcommerce_url', 'https://vault.trustcommerce.com/trans/'),
    '#description' => t('The default is: https://vault.trustcommerce.com/trans/'),
  );
  $form['trustcommerce_url_sandbox'] = array(
    '#type' => 'hidden',
    '#title' => t('URL for transactions'),
    '#default_value' => variable_get('trustcommerce_url_sandbox', 'https://vault.trustcommerce.com/trans/'),
    '#description' => t('The default is: https://vault.trustcommerce.com/trans/'),
  );
  $form['trustcommerce_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Use Live or Sandbox Settings'),
    '#default_value' => variable_get('trustcommerce_mode', 0),
    '#options' => array( 1 => t('Live'), 0 => t('Sandbox')),
    '#description' => t('Use Live for normal store operation.'),
  );
  $form['trustcommerce_avs'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Address Verification Service (AVS)'),
    '#default_value' => variable_get('trustcommerce_avs', 0),
    '#description' => t('If you enable address verification, TrustCommerce will decline the transaction if the AVS information does not match.'),
  );
  $form['trustcommerce_cvd'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Card Validation Digits (CVV2/CVC2/CID)'),
    '#default_value' => variable_get('trustcommerce_cvd', 0),
    '#description' => t('This will enable verification of the numbers on the back of the card.'),
  );
  $form['live'] = array(
    '#type' => 'fieldset',
    '#title' => t('Live Settings'),
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
    '#description' => t('You should set these values for normal operation of your store'),
  );
  $form['live']['trustcommerce_username'] = array(
    '#type' => 'textfield',
    '#title' => t('Cust Id'),
    '#default_value' => variable_get('trustcommerce_username', ''),
    '#description' => t("Enter your TrustCommerce Username."),
  );
  $form['live']['trustcommerce_password'] = array(
    '#type' => 'textfield',
    '#title' => t('Password'),
    '#default_value' => variable_get('trustcommerce_password', ''),
    '#description' => t("Enter your TrustCommerce Password."),
  );
  $form['sandbox'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sandbox Settings'),
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
    '#description' => t('You should set these values for testing the operation of your store'),
  );
  $form['sandbox']['trustcommerce_username_sandbox'] = array(
    '#type' => 'textfield',
    '#title' => t('Cust Id'),
    '#default_value' => variable_get('trustcommerce_username_sandbox', ''),
    '#description' => t("Enter your TrustCommerce Username."),
    '#required' => TRUE,
  );
  $form['sandbox']['trustcommerce_password_sandbox'] = array(
    '#type' => 'textfield',
    '#title' => t('Password'),
    '#default_value' => variable_get('trustcommerce_password_sandbox', ''),
    '#description' => t("Enter your TrustCommerce Password."),
    '#required' => TRUE,
  );
  $options = array(
    '0' => t('Decline'),
    '1' => t('Approve'),
  );

  $form['avs'] = array(
    '#type' => 'fieldset',
    '#title' => t('Address Verification Settings (AVS)'),
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
  );

  $form['cvd'] = array(
    '#type' => 'fieldset',
    '#title' => t('Card Codes Settings (CVV2/CVC2/CID)'),
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
    '#description' => t('Determine action based on response to Card Code submitted'),
  );

  $form['debug'] = array(
    '#type' => 'fieldset',
    '#title' => t('Debug Settings'),
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
    '#description' => t('Data to save for test purposes'),
  );
  $form['debug']['trustcommerce_debug'] = array(
    '#type' => 'checkbox',
    '#title' => t('Capture data to watchdog for troubleshooting'),
    '#default_value' => variable_get('trustcommerce_debug', ''),
    '#description' => t("Watchdog entries will be created for each of the items you check below."),
  );
  $form['debug']['trustcommerce_debug_request'] = array(
    '#type' => 'checkbox',
    '#title' => t('Capture data sent to TrustCommerce'),
    '#default_value' => variable_get('trustcommerce_debug_request', ''),
    '#description' => t(""),
  );
  $form['debug']['trustcommerce_debug_response'] = array(
    '#type' => 'checkbox',
    '#title' => t('Capture data received from to TrustCommerce'),
    '#default_value' => variable_get('trustcommerce_debug_response', ''),
    '#description' => t(""),
  );
  
  $actions = array(
    'preauth' => t('Pre Authorize'),
    'postauth' => t('Post Authorize'),
    'credit' => t('Credit'),
    'sale' => t('Sale'),
    'store' => t('Store'),
    'unstore' => t('Unstore'),
    'chargeback' => t('Charge Back'),
    'reversal' => t('Reversal')
  );
  
  return system_settings_form($form);
}